<?PHP // $Id$ 
      // choice.php - created with Moodle 1.4 (2004083100)


$string['allowupdate'] = 'Tillad sprgsmlet at blive opdateret';
$string['answered'] = 'Besvaret';
$string['choice'] = 'Sprgsml $a';
$string['choiceclose'] = 'Indtil';
$string['choicename'] = 'Sprgsml navn';
$string['choiceopen'] = 'ben';
$string['choicetext'] = 'Sprgsml tekst';
$string['havetologin'] = 'Du bliver ndt til at logge p fr du kan afgive dit valg.';
$string['modulename'] = 'Sprgsml';
$string['modulenameplural'] = 'Sprgsml';
$string['mustchooseone'] = 'Du skal vlge et svar fr du gemmer. Der blev ikke gemt noget.';
$string['notanswered'] = 'Ikke besvaret endnu';
$string['notopenyet'] = 'Denne aktivitet er ikke tilgngelig indtil $a';
$string['privacy'] = 'Vis ikke resultater';
$string['publish'] = 'Vis resultater';
$string['publishafteranswer'] = 'Vis resultatet til eleven efter de har svaret.';
$string['publishafterclose'] = 'Vis resultatet til studenten efter et sprgsml er lukket.';
$string['publishalways'] = 'Vis altid resultater til eleven';
$string['publishanonymous'] = 'Vis anonyme resultater uden at angive de studerendes navne';
$string['publishnames'] = 'Vis alle resultataer, med navne og sprgsml';
$string['publishnot'] = 'Vis ikke resultaterne til de studerende';
$string['responses'] = 'Besvarelser';
$string['responsesto'] = 'Besvarelser til$a';
$string['savemychoice'] = 'Gem mit sprgsml';
$string['showunanswered'] = 'Vil kolonne for ubesvaret';
$string['timerestrict'] = 'Begrns svartiden til denne tidsperiode.';
$string['viewallresponses'] = 'Se $a besvarelser';

?>
